/// <reference types="node" />
import { promises as fs, Stats, MakeDirectoryOptions } from "fs";
export declare abstract class AnyFile {
    private _path;
    constructor(path: string);
    is<T extends AnyFile>(type: FileType<T>): this is T;
    abstract verify(): Promise<boolean>;
    get path(): string;
    protected trim(path: string): string;
    get name(): string;
    get parentPath(): string;
    stat(): Promise<Stats>;
    exists(): Promise<boolean>;
    parent(): Folder;
    rename(newPath: string): Promise<void>;
    remove(): Promise<void>;
}
export declare type FileType<T extends AnyFile = AnyFile> = {
    new (path: string): T;
};
export declare class Unknown extends AnyFile {
    verify(): Promise<boolean>;
}
export declare class File extends AnyFile {
    verify(): Promise<boolean>;
    open(flags: string | number, mode?: string | number): Promise<fs.FileHandle>;
    get stem(): string;
    get suffix(): string;
    get suffixes(): string[];
}
export declare class Folder extends AnyFile {
    verify(): Promise<boolean>;
    child<T extends AnyFile>(name: string, { as }: {
        as: FileType<T>;
    }): T;
    children(opts?: {
        castable?: FileType[];
    }): Promise<AnyFile[]>;
    remove(): Promise<void>;
    make(opts?: MakeDirectoryOptions): Promise<void>;
    static make<T extends Folder>(this: FileType<T>, path: string, opts?: MakeDirectoryOptions): Promise<T>;
}
